import { WorkflowContextOpts } from '../common/types';
import { EventContainerSupport } from './event-container-support';
import type { LcdpRenderContext } from '@fly-vue/lcdp-engine';
export declare function buildDefaultApprovalOperations(): any[];
export declare class WorkflowContext extends EventContainerSupport {
    taskId: string;
    processInstanceId: string;
    mockSchemaId: string;
    page: any;
    variableFilters: null;
    taskStatus: {
        STARTED: string;
        CREATED: string;
        ASSIGNED: string;
        SUSPENDED: string;
        COMPLETED: string;
        CANCELLED: string;
        DELETED: string;
        WITHDRAW: string;
        REJECT: string;
        REJECTED: string;
    };
    processInstanceStatus: {
        STARTED: string;
        CREATED: string;
        RUNNING: string;
        COMPLETED: string;
        SUSPENDED: string;
        CANCELLED: string;
        DELETED: string;
    };
    processInstance: any;
    task: any;
    processDefinitionKey: string;
    processDefinitionId: string;
    businessKey: string;
    state: string;
    submitType: string;
    getProcessModelJson: any;
    getProcessModelXml: any;
    getCurrentTaskDef: any;
    processModelJson: any;
    taskElement: any;
    formRenderContext: LcdpRenderContext;
    private _outVariables;
    _taskVariablesDef: any;
    private _appInfo;
    private _historyTasks;
    private _iframeBeforeSubmit;
    private _iframeSetWaitVariables;
    constructor({ taskId, processDefinitionKey, processInstanceId, data, mockSchemaId, page, variableFilters }: WorkflowContextOpts);
    /**
     * 初始化流程相关数据：
     * - 根据taskId，填充task
     * - 根据task.processInstanceId或processInstanceId实始化processInstance
     */
    init(): Promise<any>;
    _buildRequestOpts(): {
        headers: {
            'x-mock-test': any;
        };
    };
    /**
     * 获取流程任务
     */
    getTask(): Promise<any>;
    startProcessByKey: (params: any) => any;
    currentApprovalOperations: () => any;
    getCurrentApprovalNames: () => {
        approve: string;
        reject: string;
        rejectToPrevious: string;
        customReject: string;
        resubmit: string;
        transfer: string;
        addCandidates: string;
        cancel: string;
        circulate: string;
        urge: string;
    };
    getCurrentOpinionLayout: () => any;
    isDraft: () => boolean;
    getProcessInstance: () => Promise<any>;
    reloadProcessInstance: () => Promise<void>;
    getHistoryVariables: (processInstanceId: any) => any;
    getTaskVariablesDef: () => Promise<any>;
    getVariableDef: (id: any) => any;
    rebuildHistoryVariables: (variables: any) => {};
    getProcessHistory: (processInstanceId: any, reload: any) => Promise<any>;
    getHistoryActsForReject: (processInstanceId: any) => any;
    /**
     * 获取当前任务的变量，如果不传变更名，则返回所有变量
     * @param {string} name 变更名
     */
    getTaskVariables: (name: any) => {};
    /**
     * 获取流程实例的变量
     */
    getProcessVariables: () => {};
    /**
     * 查找variable，先在task中查找，再在process中
     * @param name
     */
    getVariable: (name: any) => any;
    getVariableValue: (name: any) => any;
    getCommentTitle: () => any;
    /**
     * 获取当前流程的流程表单
     */
    getFormKey: () => any;
    getBusinessKey: () => any;
    private _processDefinition;
    /**
     * 获取当前流程对应的流程定义
     */
    getProcessDefinition: () => Promise<any>;
    /**
     * 向流程添加输出变量
     * @param variables
     * @isProcessVariable 是否是流程级别变量
     */
    addOutVariables: (variables: any, isProcessVariable: any) => void;
    /**
     * 向流程添加process级别的变量
     * @param variables
     */
    addProcessVariables: (variables: any) => void;
    setSubmitType: (submitType: any) => void;
    getSubmitType: () => any;
    /**
     * 设置businessKey值
     * @param key
     */
    setBusinessKey: (key: any) => void;
    /**
     * 获取流程是否可以被撤回，撤回条件：由当前task生成的待办还未被审批
     * @param taskId
     */
    isWithdraw: () => Promise<any>;
    isTaskFinished: (taskEntity: any) => boolean;
    isProcessFinished: (proc: any) => boolean;
    /**
     * 撤回task
     * @param taskId
     */
    withdrawTask: (opinion: any) => Promise<any>;
    /**
     * 终止流程
     * @param processInstanceId
     */
    jumpToEnd: (opinion: any) => Promise<any>;
    getState: () => any;
    setCurrentTaskId: (taskId: any) => Promise<void>;
    /**
     * 获取应用所属流程信息
     */
    getAppInfo: (appId: any) => Promise<any>;
    /**
     * 解析流程的表单配置
     * @param {*} formKey
     */
    parseFormSetting: (formKey: any) => any;
    /**
     * 获取流程预览轨迹数据
     */
    predict: (variables: any) => Promise<any>;
}
